@@ -46,6 +46,7 @@
 #include <QDir>
 #include <QTimer>
 #include <QStandardPaths>
+#include <QRandomGenerator>
 
 #include <memory>
 
@@ -115,11 +116,11 @@ GameManagerPrivate::GameManagerPrivate()
 	  initComplete(false),
 	  loading(false) {
 
-	const QDir dir = QStandardPaths::locate(QStandardPaths::AppDataLocation, QLatin1String("sounds"), QStandardPaths::LocateDirectory);
-	captureWhiteSound = std::unique_ptr<KgSound>( new KgSound(dir.filePath(QLatin1String("capture_white.ogg"))) );
-	captureBlackSound = std::unique_ptr<KgSound>( new KgSound(dir.filePath(QLatin1String("capture_black.ogg"))) );
-	moveWhiteSound = std::unique_ptr<KgSound>( new KgSound(dir.filePath(QLatin1String("move_white.ogg"))) ) ;
-	moveBlackSound = std::unique_ptr<KgSound>( new KgSound(dir.filePath(QLatin1String("move_black.ogg"))) );
+	const QDir dir = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("sounds"), QStandardPaths::LocateDirectory);
+	captureWhiteSound = std::unique_ptr<KgSound>( new KgSound(dir.filePath(QStringLiteral("capture_white.ogg"))) );
+	captureBlackSound = std::unique_ptr<KgSound>( new KgSound(dir.filePath(QStringLiteral("capture_black.ogg"))) );
+	moveWhiteSound = std::unique_ptr<KgSound>( new KgSound(dir.filePath(QStringLiteral("move_white.ogg"))) ) ;
+	moveBlackSound = std::unique_ptr<KgSound>( new KgSound(dir.filePath(QStringLiteral("move_black.ogg"))) );
 }
 
 int GameManagerPrivate::nextOfferId() {
@@ -178,7 +179,7 @@ void Manager::setCurrentTime(Color color, const QTime& time) {
 	default:
 		return;
 	}
-	emit timeChanged ( color, time );
+	Q_EMIT timeChanged ( color, time );
 }
 
 void Manager::timerEvent(QTimerEvent* ) {
@@ -201,18 +202,18 @@ void Manager::timerEvent(QTimerEvent* ) {
 		time = QTime();
 		break;
 	}
-	emit timeChanged(d->activePlayer, time);
+	Q_EMIT timeChanged(d->activePlayer, time);
 }
 
 void Manager::addMoveToHistory(const Move& move) {
 	Q_D(GameManager);
 	if ( d->moveHistory.isEmpty() )
-		emit undoPossible(true);
+		Q_EMIT undoPossible(true);
 	d->moveHistory << move;
 	if ( !d->moveUndoStack.isEmpty() )
-		emit redoPossible(false);
+		Q_EMIT redoPossible(false);
 	d->moveUndoStack.clear();
-	emit historyChanged();
+	Q_EMIT historyChanged();
 }
 
 Move Manager::nextUndoMove() {
@@ -222,14 +223,14 @@ Move Manager::nextUndoMove() {
 		d->whiteTimeControl.currentTime = m.time();
 	else
 		d->blackTimeControl.currentTime = m.time();
-	emit timeChanged ( m.pieceData().first, m.time() );
+	Q_EMIT timeChanged ( m.pieceData().first, m.time() );
 	if ( d->moveHistory.isEmpty() )
-		emit undoPossible(false);
+		Q_EMIT undoPossible(false);
 	if ( d->moveUndoStack.isEmpty() )
-		emit redoPossible(true);
+		Q_EMIT redoPossible(true);
 	d->moveUndoStack.push( m );
 
-	emit historyChanged();
+	Q_EMIT historyChanged();
 
 	Move ret = m.reverse();
 	qCDebug(LOG_KNIGHTS) << m << ret;
@@ -241,12 +242,12 @@ Move Manager::nextRedoMove() {
 	Q_D(GameManager);
 	Move m = d->moveUndoStack.pop();
 	if ( d->moveUndoStack.isEmpty() )
-		emit redoPossible(false);
+		Q_EMIT redoPossible(false);
 	if ( d->moveHistory.isEmpty() )
-		emit undoPossible(true);
+		Q_EMIT undoPossible(true);
 	d->moveHistory << m;
 	m.setFlag ( Move::Forced, true );
-	emit historyChanged();
+	Q_EMIT historyChanged();
 
 	return m;
 }
@@ -259,7 +260,7 @@ void Manager::setActivePlayer(Color player) {
 
 void Manager::changeActivePlayer() {
 	setActivePlayer ( oppositeColor ( activePlayer() ) );
-	emit activePlayerChanged ( activePlayer() );
+	Q_EMIT activePlayerChanged ( activePlayer() );
 }
 
 Color Manager::activePlayer() const {
@@ -276,7 +277,6 @@ void Manager::initialize() {
 	d->activePlayer = White;
 	d->whiteTimeControl.currentTime = d->whiteTimeControl.baseTime;
 	d->blackTimeControl.currentTime = d->blackTimeControl.baseTime;
-	QList<Protocol*> protocols;
 	Protocol::white()->setTimeControl(d->whiteTimeControl);
 	Protocol::black()->setTimeControl(d->blackTimeControl);
 	connect ( Protocol::white(), &Protocol::pieceMoved, this, &Manager::moveByProtocol );
@@ -293,7 +293,7 @@ void Manager::initialize() {
 void Manager::pause(bool pause) {
 	Offer o;
 	o.action = pause ? ActionPause : ActionResume;
-	o.id = qrand();
+	o.id = QRandomGenerator::global()->bounded(RAND_MAX);
 	o.player = NoColor;
 	sendOffer(o);
 }
@@ -366,7 +366,7 @@ void Manager::redo() {
 	Move m = nextRedoMove();
 	Protocol::white()->move ( m );
 	Protocol::black()->move ( m );
-	emit pieceMoved ( m );
+	Q_EMIT pieceMoved ( m );
 	changeActivePlayer();
 }
 
@@ -415,7 +415,7 @@ void Manager::protocolInitSuccesful() {
 			}
 			if (!d->initComplete) {
 				d->initComplete = true;
-				emit initComplete();
+				Q_EMIT initComplete();
 			}
 		}
 	}
@@ -432,7 +432,7 @@ void Manager::startGame() {
 	Protocol::white()->startGame();
 	Protocol::black()->startGame();
 	d->gameStarted = true;
-	emit historyChanged();
+	Q_EMIT historyChanged();
 }
 
 void Manager::gameOver(Color winner) {
@@ -448,7 +448,7 @@ void Manager::gameOver(Color winner) {
 	stopTime();
 	Protocol::white()->setWinner(winner);
 	Protocol::black()->setWinner(winner);
-	emit winnerNotify(winner);
+	Q_EMIT winnerNotify(winner);
 
 	reset();
 	d->gameOverInProcess = false;
@@ -474,8 +474,8 @@ void Manager::reset() {
 	//it should be possible to study the history after the game ended.
 
 	d->moveUndoStack.clear();
-	emit undoPossible( false );
-	emit redoPossible( false );
+	Q_EMIT undoPossible( false );
+	Q_EMIT redoPossible( false );
 
 	d->offers.clear();
 	d->usedOfferIds.clear();
@@ -538,7 +538,7 @@ void Manager::sendOffer(const Offer& offer) {
 	Protocol* opp = Protocol::byColor( oppositeColor(o.player) );
 	// Only display a notification if only one player is local.
 	if ( opp->isLocal() && !Protocol::byColor(o.player)->isLocal() )
-		emit notification(o);
+		Q_EMIT notification(o);
 	else
 		opp->makeOffer(o);
 }
@@ -550,7 +550,7 @@ void Manager::setOfferResult(int id, OfferAction result) {
 		switch ( d->offers[id].action ) {
 		case ActionUndo:
 			for ( int i = 0; i < d->offers[id].numberOfMoves; ++i ) {
-				emit pieceMoved ( nextUndoMove() );
+				Q_EMIT pieceMoved ( nextUndoMove() );
 				changeActivePlayer();
 			}
 			break;
@@ -611,7 +611,7 @@ void Manager::sendPendingMove() {
 	if ( pendingMove.isValid() && isGameActive() ) {
 		Q_D(GameManager);
 		Protocol::byColor ( oppositeColor ( d->activePlayer ) )->move ( pendingMove );
-		emit pieceMoved ( pendingMove );
+		Q_EMIT pieceMoved ( pendingMove );
 		rules()->moveMade ( pendingMove );
 
 		if ( Settings::speakOpponentsMoves()
@@ -686,7 +686,10 @@ void Manager::sendPendingMove() {
 		default:
 			break;
 		}
-		changeActivePlayer();
+
+		//don't change the active player if the game is already over
+		if (d->gameStarted)
+			changeActivePlayer();
 	}
 }
 
@@ -848,7 +851,7 @@ void Manager::loadGameHistoryFrom(const QString& filename) {
 		}
 	}
 
-	emit playerNameChanged();
+	Q_EMIT playerNameChanged();
 }
 
 void Manager::saveGameHistoryAs(const QString& filename) {
@@ -866,7 +869,7 @@ void Manager::saveGameHistoryAs(const QString& filename) {
 
         stream << "[Event \"Casual Game\"]" << "\n";
         stream << "[Site \"?\"]" << "\n";
-        stream << "[Date \"" << QDate::currentDate().toString( QLatin1String("yyyy.MM.dd") ) << "\"]" << "\n";
+        stream << "[Date \"" << QDate::currentDate().toString( QStringLiteral("yyyy.MM.dd") ) << "\"]" << "\n";
         stream << "[Round \"-\"]" << "\n";
         stream << "[White \"" << Protocol::white()->playerName() << "\"]" << "\n";
         stream << "[Black \"" << Protocol::black()->playerName() << "\"]" << "\n";
