@@ -55,7 +55,7 @@ const char* currentPlayerPattern = "([WB]) \\-?\\d+ \\d+ \\d+ \\d+ \\d+ \\d+ \\d
 const char* offerPattern = "<pf> (\\d+) w=([a-zA-Z\\(\\)]+) t=([a-z]+) p=(.+)";
 
 FicsProtocol::FicsProtocol ( QObject* parent ) : TextProtocol ( parent ),
-	movePattern(QString(QLatin1String("[%1]\\/(%2)\\-(%3)(=[%4])?"))
+	movePattern(QStringLiteral("[%1]\\/(%2)\\-(%3)(=[%4])?")
 	            .arg ( QLatin1String(pieces) )
 	            .arg ( QLatin1String(coordinate) )
 	            .arg ( QLatin1String(coordinate) )
@@ -97,7 +97,7 @@ FicsProtocol::FicsProtocol ( QObject* parent ) : TextProtocol ( parent ),
 	m_chat(nullptr)
     {
 	// FICS games are always time-limited
-	setAttribute ( QLatin1String("TimeLimitEnabled"), true );
+	setAttribute ( QStringLiteral("TimeLimitEnabled"), true );
 
     //TODO: this initialization is obsolete since the time control _should_ be set
     //when a new game is started and the values provided in the game dialog are used.
@@ -128,10 +128,10 @@ void FicsProtocol::init (  ) {
 	m_stage = ConnectStage;
 
 	ChatWidget* console = createConsoleWidget();
-	console->addExtraButton ( QLatin1String("seek"), i18nc("Start searching for opponents", "Seek"), QLatin1String("edit-find") );
-	console->addExtraButton ( QLatin1String("unseek"), i18nc("Stop searching for opponents", "Unseek"), QLatin1String("edit-clear") );
-	console->addExtraButton ( QLatin1String("accept"), i18n("Accept"), QLatin1String("dialog-ok-accept") );
-	console->addExtraButton ( QLatin1String("help"), i18n("Help"), QLatin1String("help-contents") );
+	console->addExtraButton ( QStringLiteral("seek"), i18nc("Start searching for opponents", "Seek"), QStringLiteral("edit-find") );
+	console->addExtraButton ( QStringLiteral("unseek"), i18nc("Stop searching for opponents", "Unseek"), QStringLiteral("edit-clear") );
+	console->addExtraButton ( QStringLiteral("accept"), i18n("Accept"), QStringLiteral("dialog-ok-accept") );
+	console->addExtraButton ( QStringLiteral("help"), i18n("Help"), QStringLiteral("help-contents") );
 	connect ( console, &ChatWidget::sendText, this, &FicsProtocol::writeCheckMoves );
 	setConsole ( console );
 
@@ -141,7 +141,11 @@ void FicsProtocol::init (  ) {
 	int port = attribute("port").toInt();
 	if ( port == 0 )
 		port = 5000;
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+	connect ( socket, &QTcpSocket::errorOccurred,
+#else
 	connect ( socket, static_cast<void (QTcpSocket::*)(QAbstractSocket::SocketError)> (&QTcpSocket::error),
+#endif
 	          this, &FicsProtocol::socketError );
 
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
@@ -154,7 +158,7 @@ QList< Protocol::ToolWidgetData > FicsProtocol::toolWidgets() {
 	ToolWidgetData consoleData;
 	consoleData.widget = console();
 	consoleData.title = i18n("Server Console");
-	consoleData.name = QLatin1String("console");
+	consoleData.name = QStringLiteral("console");
 	consoleData.type = ConsoleToolWidget;
 	consoleData.owner = color();
 
@@ -166,7 +170,7 @@ QList< Protocol::ToolWidgetData > FicsProtocol::toolWidgets() {
 	ToolWidgetData chatData;
 	chatData.widget = m_chat;
 	chatData.title = i18n("Chat with %1", playerName());
-	chatData.name = QLatin1String("chat");
+	chatData.name = QStringLiteral("chat");
 	chatData.type = ChatToolWidget;
 
 	return QList<ToolWidgetData>() << consoleData << chatData;
@@ -174,7 +178,7 @@ QList< Protocol::ToolWidgetData > FicsProtocol::toolWidgets() {
 
 void FicsProtocol::socketError() {
 	QApplication::restoreOverrideCursor();
-	emit error( NetworkError, device()->errorString() );
+	Q_EMIT error( NetworkError, device()->errorString() );
 }
 
 void FicsProtocol::login ( const QString& username, const QString& password ) {
@@ -207,11 +211,11 @@ void FicsProtocol::openGameDialog() {
 
 	bBox->button(QDialogButtonBox::Ok)->setText(i18n("Accept"));
 	bBox->button(QDialogButtonBox::Ok)->setVisible(false);
-	bBox->button(QDialogButtonBox::Ok)->setIcon(QIcon::fromTheme(QLatin1String("dialog-ok-accept")));
+	bBox->button(QDialogButtonBox::Ok)->setIcon(QIcon::fromTheme(QStringLiteral("dialog-ok-accept")));
 
 	bBox->button(QDialogButtonBox::Cancel)->setText(i18n("Decline"));
 	bBox->button(QDialogButtonBox::Cancel)->setVisible(false);
-	bBox->button(QDialogButtonBox::Cancel)->setIcon(QIcon::fromTheme(QLatin1String("dialog-close")));
+	bBox->button(QDialogButtonBox::Cancel)->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
 
 	m_widget = new FicsDialog ();
 	m_widget->setServerName ( attribute( "server" ).toString());
@@ -287,7 +291,7 @@ bool FicsProtocol::parseLine(const QString& line) {
 				name.truncate ( name.indexOf ( QLatin1Char ( ' ' ) ) );
 			qCDebug(LOG_KNIGHTS) << QLatin1String("Your name is") << name;
 			otherPlayerName = name;
-			emit sessionStarted();
+			Q_EMIT sessionStarted();
 		} else if ( line.contains ( QLatin1String("Invalid password") ) ) {
 			m_widget->setLoginEnabled ( true );
 			type = ChatWidget::AccountMessage;
@@ -297,14 +301,14 @@ bool FicsProtocol::parseLine(const QString& line) {
 	case SeekStage:
 		if ( line.startsWith( QLatin1String("<sc>") ) ) {
 			display = false;
-			emit clearSeeks();
+			Q_EMIT clearSeeks();
 		} else if ( line.startsWith( QLatin1String("<sr>") ) ) {
 			display = false;
 			for ( const QString& str : line.split(QLatin1Char(' ') ) ) {
 				bool ok;
 				int id = str.toInt(&ok);
 				if ( ok )
-					emit gameOfferRemoved(id);
+					Q_EMIT gameOfferRemoved(id);
 			}
 		} else if ( line.startsWith( QLatin1String("<s>") ) && seekExp.indexIn(line) > -1 ) {
 			display = false;
@@ -323,7 +327,7 @@ bool FicsProtocol::parseLine(const QString& line) {
 			offer.ratingRange.second = seekExp.cap(n++).toInt();
 			offer.automatic = ( !seekExp.cap(n).isEmpty() && seekExp.cap(n++)[0] == QLatin1Char('t') );
 			offer.formula = ( !seekExp.cap(n).isEmpty() && seekExp.cap(n++)[0] == QLatin1Char('t') );
-			emit gameOfferReceived ( offer );
+			Q_EMIT gameOfferReceived ( offer );
 		} else if ( line.startsWith( QLatin1String("<pf>") ) && challengeExp.indexIn ( line ) > -1 ) {
 			display = false;
 			FicsChallenge challenge;
@@ -331,14 +335,14 @@ bool FicsProtocol::parseLine(const QString& line) {
 			challenge.player.first = challengeExp.cap ( 2 );
 			int ratingPos = ( challengeExp.cap(2) == challengeExp.cap(3) ) ? 4 : 6;
 			challenge.player.second = challengeExp.cap ( ratingPos ).toInt();
-			emit challengeReceived ( challenge );
+			Q_EMIT challengeReceived ( challenge );
 		} else if ( line.startsWith( QLatin1String("<pr>") ) ) {
 			display = false;
 			for ( const QString& str : line.split( QLatin1Char(' ') ) ) {
 				bool ok;
 				int id = str.toInt(&ok);
 				if ( ok )
-					emit challengeRemoved(id);
+					Q_EMIT challengeRemoved(id);
 			}
 		} else if ( gameStartedExp.indexIn ( line ) > -1 ) {
 			qCDebug(LOG_KNIGHTS) << "Game Started" << line;
@@ -409,7 +413,7 @@ bool FicsProtocol::parseLine(const QString& line) {
 					}
 				}
 				qCDebug(LOG_KNIGHTS) << "Valid move" << m;
-				emit pieceMoved ( m );
+				Q_EMIT pieceMoved ( m );
 			}
 			Manager::self()->setCurrentTime ( White, QTime().addSecs ( whiteTimeLimit ) );
 			Manager::self()->setCurrentTime ( Black, QTime().addSecs ( blackTimeLimit ) );
@@ -442,15 +446,15 @@ bool FicsProtocol::parseLine(const QString& line) {
 		else if ( line.startsWith(QLatin1Char('{')) && line.contains(QLatin1Char('}'))) {
 			if ( line.endsWith ( QLatin1String("1-0") ) ) {
 				type = ChatWidget::AccountMessage;
-				emit gameOver ( White );
+				Q_EMIT gameOver ( White );
 			} else if ( line.endsWith ( QLatin1String("1/2-1/2") ) || line.endsWith ( QLatin1Char('*') ) ) {
 				// Knights has no way of reporting aborted or unfinished games
 				// so we report aborted games as draws
 				type = ChatWidget::AccountMessage;
-				emit gameOver ( NoColor );
+				Q_EMIT gameOver ( NoColor );
 			} else if ( line.endsWith ( QLatin1String("0-1") ) ) {
 				type = ChatWidget::AccountMessage;
-				emit gameOver ( Black );
+				Q_EMIT gameOver ( Black );
 			}
 		}
 	}
@@ -485,7 +489,7 @@ void FicsProtocol::declineChallenge ( int id ) {
 }
 
 void FicsProtocol::dialogRejected() {
-	emit error ( UserCancelled );
+	Q_EMIT error ( UserCancelled );
 }
 
 void FicsProtocol::setSeeking ( bool seek ) {
