@@ -124,11 +124,11 @@ Color Protocol::color() const {
 }
 
 void Protocol::setPlayerName ( const QString& name ) {
-	setAttribute ( QLatin1String ( "PlayerName" ), name );
+	setAttribute ( QStringLiteral ( "PlayerName" ), name );
 }
 
 QString Protocol::playerName() const {
-	return attribute ( QLatin1String ( "PlayerName" ) ).toString();
+	return attribute ( QStringLiteral ( "PlayerName" ) ).toString();
 }
 
 void Protocol::setAttribute ( const QString& attribute, QVariant value ) {
@@ -142,7 +142,9 @@ void Protocol::setAttribute ( const char* attribute, QVariant value ) {
 
 void Protocol::setAttributes ( QVariantMap attributes ) {
 	Q_D ( Protocol );
-	d->attributes.unite ( attributes );
+	for (auto it = attributes.constBegin(), end = attributes.constEnd(); it != end; ++it) {
+		d->attributes.insert(it.key(), it.value());
+	}
 }
 
 QVariant Protocol::attribute ( const QString& attribute ) const {
@@ -195,7 +197,7 @@ ChatWidget* Protocol::createConsoleWidget() {
 void Protocol::initComplete() {
 	Q_D(Protocol);
 	d->ready = true;
-	emit initSuccesful();
+	Q_EMIT initSuccesful();
 }
 
 bool Protocol::isReady() {
