@@ -61,7 +61,7 @@ bool UciProtocol::parseLine(const QString& line) {
 		write ( "isready" );
 	} else if ( line.startsWith ( QLatin1String("readyok") ) ) {
 		type = ChatWidget::AccountMessage;
-		emit initComplete();
+		initComplete();
 	} else if ( line.startsWith ( QLatin1String("id name ") ) ) {
 		type = ChatWidget::AccountMessage;
 		// Chop off the "id name " port, the remainder if the engine's name
@@ -72,7 +72,7 @@ bool UciProtocol::parseLine(const QString& line) {
 		if ( lst.size() > 1 ) {
 			Move m = Move ( lst[1] );
 			mMoveHistory << m;
-			emit pieceMoved ( m );
+			Q_EMIT pieceMoved ( m );
 		} else
 			return false;
 		if ( lst.size() > 3 && lst[2] == QLatin1String("ponder") )
@@ -111,11 +111,11 @@ void UciProtocol::move(const Knights::Move& m) {
 }
 
 void UciProtocol::requestNextMove() {
-	QString str = QLatin1String("position startpos");
+	QString str = QStringLiteral("position startpos");
 
 	if ( !mMoveHistory.isEmpty() ) {
 		str += QLatin1String(" moves");
-		for ( const Move& move : mMoveHistory ) {
+		for ( const Move& move : qAsConst(mMoveHistory) ) {
 			QString moveString = QLatin1Char(' ') + move.from().string() + move.to().string();
 			if ( move.promotedType() )
 				moveString += Piece::charFromType ( move.promotedType() ).toLower();
@@ -124,7 +124,7 @@ void UciProtocol::requestNextMove() {
 	}
 	write ( str );
 
-	QString goString = QLatin1String("go");
+	QString goString = QStringLiteral("go");
 
 	//TODO: mDifficulty doesn't seem to be properly set nowhere
 	if ( mDifficulty )
